@@ -2,14 +2,13 @@ from serializers.serializer import (
     Serializer,
     ObjectSerializer,
     ModelSerializer,
-    DumpDataSerializer
 )
 from serializers.fields import (
     Field,
-    ModelField,
     RelatedField,
     PrimaryKeyRelatedField,
     NaturalKeyRelatedField,
 )
+from serializers.fixture_serializer import FixtureSerializer
 
-__version__ = '0.5.1'
+__version__ = '0.6.0'
